Struct postmark_client::bounce::BouncesQueryParamaters[][src]

pub struct BouncesQueryParamaters {
    pub count: u16,
    pub offset: u16,
    pub bounce_type: Option<String>,
    pub inactive: Option<bool>,
    pub email_filter: Option<String>,
    pub tag: Option<String>,
    pub message_id: Option<String>,
    pub from_date: Option<String>,
    pub to_date: Option<String>,
    pub message_stream: Option<String>,
}

Fields

count: u16

Number of bounces to return per request. Max 500. Count + Offset cannot exceed 10,000 bounces.

offset: u16

Number of bounces to skip. Count + Offset cannot exceed 10,000 bounces.

bounce_type: Option<String>

Filter by type of bounce

inactive: Option<bool>

Filter by emails that were deactivated by Postmark due to the bounce. Set to true or false. If this isn’t specified it will return both active and inactive.

email_filter: Option<String>

Filter by email address

tag: Option<String>

Filter by tag

message_id: Option<String>

Filter by messageID

from_date: Option<String>

Filter messages starting from the date/time specified (inclusive). e.g. 2021-01-01T12:00:00. Our API uses Eastern Time Zone.

to_date: Option<String>

Filter messages up to the date/time specified (inclusive). e.g. 2021-01-01T12:00:00. Our API uses Eastern Time Zone.

message_stream: Option<String>

Filter by message stream ID. If not provided, message will default to the outbound transactional stream.

Implementations

Creates a new BouncesQueryParameters requiring the minimum parameters