Struct postmark_client::client::Client[][src]

pub struct Client { /* fields omitted */ }
Client exposes the Postmark functionality to be easily used within rust applications.

The client can create its own internal reqwest::Client or one can be provided if there are specific configurations desired by the application.

Implementations

Sends a batch of Emails in a single request, each email in the batch has a corresponding EmailResponse in the result of this function.

https://postmarkapp.com/developer/api/email-api#send-batch-emails

Sends a batch of template emails in a single request, each email in the batch has a corresponding EmailResoinse in the result of this function.

https://postmarkapp.com/developer/api/templates-api#send-batch-with-templates

Lists all the bounce stats for the server the token is associated with.

https://postmarkapp.com/developer/api/bounce-api#delivery-stats

The bounces search allows you to return up-to 10,000 bounces in a search. For searches where you’re looking to retrieve more than 10,000 bounces use parameters like todate and fromdate to filter the messages.

https://postmarkapp.com/developer/api/bounce-api#bounces

Gets a single bounced email using the provided ID.

https://postmarkapp.com/developer/api/bounce-api#single-bounce

Gets the SMTP dump for the bounced email.

https://postmarkapp.com/developer/api/bounce-api#bounce-dump

Reactivates thes email address in the bounced email

https://postmarkapp.com/developer/api/bounce-api#activate-bounce

Create a new postmark client with the provided token

Create a new postmark client with the provided reqwest client and token