Struct postmark_client::client::Client[][src]

pub struct Client { /* fields omitted */ }
Client exposes the Postmark functionality to be easily used within rust applications.

The client can create its own internal reqwest::Client or one can be provided if there are specific configurations desired by the application.

Implementations

Create a new postmark client with the provided token

Create a new postmark client with the provided reqwest client and token

Sends a batch of Emails in a single request, each email in the batch has a corresponding EmailResponse in the result of this function.

https://postmarkapp.com/developer/api/email-api#send-batch-emails

Sends a batch of template emails in a single request, each email in the batch has a corresponding EmailResoinse in the result of this function.

https://postmarkapp.com/developer/api/templates-api#send-batch-with-templates