Struct postmark_client::client::Client [−][src]
pub struct Client { /* fields omitted */ }Expand description
Client exposes the Postmark functionality to be easily used within rust applications.
The client can create its own internal reqwest::Client or one can be provided if there are specific configurations desired by the application.
Implementations
pub async fn send_batch_emails(
&self,
emails: &[Email]
) -> Result<Vec<EmailResponse>, PostmarkClientError>
pub async fn send_batch_emails(
&self,
emails: &[Email]
) -> Result<Vec<EmailResponse>, PostmarkClientError>
Sends a batch of Emails in a single request, each email in the batch has a corresponding EmailResponse in the result of this function.
https://postmarkapp.com/developer/api/email-api#send-batch-emails
pub async fn send_batch_template_emails<M>(
&self,
email: &[TemplatedEmail<M>]
) -> Result<EmailResponse, PostmarkClientError> where
M: Serialize,
pub async fn send_batch_template_emails<M>(
&self,
email: &[TemplatedEmail<M>]
) -> Result<EmailResponse, PostmarkClientError> where
M: Serialize,
Sends a batch of template emails in a single request, each email in the batch has a corresponding EmailResoinse in the result of this function.
https://postmarkapp.com/developer/api/templates-api#send-batch-with-templates
pub async fn send_template_email<M>(
&self,
email: &TemplatedEmail<M>
) -> Result<EmailResponse, PostmarkClientError> where
M: Serialize,
pub async fn send_template_email<M>(
&self,
email: &TemplatedEmail<M>
) -> Result<EmailResponse, PostmarkClientError> where
M: Serialize,
Sends a template email.
https://postmarkapp.com/developer/api/templates-api#email-with-template